<!--Copyright 2015 Cisco Systems, Inc. All rights reserved.-->

<!--Licensed under the Apache License, Version 2.0 (the "License"); you may-->
<!--not use this file except in compliance with the License. You may obtain-->
<!--a copy of the License at-->

<!--http://www.apache.org/licenses/LICENSE-2.0-->

<!--Unless required by applicable law or agreed to in writing, software-->
<!--distributed under the License is distributed on an "AS IS" BASIS, WITHOUT-->
<!--WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the-->
<!--License for the specific language governing permissions and limitations-->
<!--under the License.-->

<img class="background" src="images/back.jpg">

<div id="page-login" class="row">
  <div class="col-xs-12 col-md-6 col-md-offset-3 col-sm-6 col-sm-offset-3">
    <div class="box">
      <div class="box-content">
        <div class="text-center">
          <h3 class="page-header">Login</h3>
        </div>

        <h4>Server Cloud</h4>
        <div class="form-group">
          <div>
            <label>admin.openrc.sh:</label>
            <input class="btn" type="file" id="file1" name="file1" enctype="multipart/form-data" />
          </div>


          <div class="input-group"  style="margin:0 auto">
            <span class="input-group-addon">Password</span>
            <input type="password" class="form-control" id="inputPassword1" ng-model="inputPassword1" placeholder="Input Your Server Cloud's Password">
          </div>

        </div>

        <hr/>

        <h4>Client Cloud</h4>
        <div class="checkbox">
          <h5>
            <label>
              <input type="checkbox" ng-model="samecloud" ng-click="clouds()"> Same as Server Cloud
            </label>
          </h5>
        </div>
        <div class="form-group">
          <div>
            <label>admin.openrc.sh:</label>
            <input class="btn" type="file" id="file2" name="file2" enctype="multipart/form-data" disabled/>
          </div>

          <div class="input-group"  style="margin:0 auto">
            <span class="input-group-addon">Password</span>
            <input type="password" class="form-control" id="inputPassword2" ng-model="inputPassword2" placeholder="Input Your Client Cloud's Password" disabled>
          </div>
        </div>

        <div class="text-center">
          <a href="" class="btn btn-primary" ng-click="setConfig()">Sign in</a>
        </div>

      </div>
    </div>
  </div>
</div>
<br/>
